﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MediaPortal.GUI.Library;
using MediaPortal.Configuration;


namespace StarDate
{
    public class StarDate : GUIWindow, ISetupForm, IShowPlugin
    {
        int UPDATE_TIME = 1; //1 second default
        int OFFSET_YEARS = 0; 

        public static string SectionName = "StarDate";

        public StarDate()
        {
            Log.Info("[StarDate started]");
            //Load settings
            try
            {
                using (var xmlreader = new MediaPortal.Profile.Settings(Config.GetFile(Config.Dir.Config, "StarDate.xml")))
                {
                    OFFSET_YEARS = Convert.ToInt32(xmlreader.GetValueAsString(SectionName, "OffsetYears", "0"));
                    UPDATE_TIME = Convert.ToInt32(xmlreader.GetValueAsString(SectionName, "UpdateSeconds", "5"));
                }
            }
            catch (Exception exc)
            {
                Log.Debug("[StarDate] StarDateSetup: Error LoadSettings: Exception " + exc.Message);
            }
            System.Threading.Thread stardatethread = new System.Threading.Thread(CalculateStarDate);
            stardatethread.Start();
        }
        ~StarDate()
        {
            Log.Info("[~StarDate finished]");
        }

        #region ISetupForm

        public string PluginName()
        {
            return "StarDate";
        }
        public string Description() // Return the description which should b shown in the plugin menu
        {
            return "Calculate Star date for LCARS Skin";
        }
        public string Author() // Return the author which should b shown in the plugin menu
        {
            return "huha";
        }
        public bool CanEnable() // Indicates whether plugin can be enabled/disabled
        {
            return true;
        }
        public bool HasSetup()
        {
            return true;
        }
        public bool DefaultEnabled() // Indicates if plugin is enabled by default;
        {
            return true;
        }
        public int GetWindowId() // get ID of plugin window
        {
            return 0;
        }
        public bool GetHome(out string strButtonText, out string strButtonImage, out string
          strButtonImageFocus, out string strPictureImage)
        {
            strButtonText = null;
            strButtonImage = null;
            strButtonImageFocus = null;
            strPictureImage = null;
            return false;
        }


        // With GetID it will be an window-plugin / otherwise a process-plugin
        // Enter the id number here again
        public override int GetID
        {
            set
            {
            }
        }

        public bool ShowDefaultHome()
        {
            return false;
        }

        // show the setup dialog
        public void ShowPlugin()
        {
            var form = new StarDateSetup();
            form.ShowDialog();
        }

        #endregion

        

        public void CalculateStarDate()
        {
            while (1 == 1) //endless loop
            {
                System.Threading.Thread.Sleep(UPDATE_TIME * 1000);
                DateTime actual = DateTime.Now;
                int d = actual.DayOfYear;
                int y = actual.Year;
                int h = actual.Hour;
                int m = actual.Minute;
                int s = actual.Second;
                double stardate = (y + OFFSET_YEARS + ((((( (m + (s /60.0)) / 60.0) + h) / 24.0) + (d - 1.0) / 265.24)) - 2323.0) * 1000.0;
                string str_stardate = string.Format("{0:F3}", stardate);
                
                /*
                Log.Debug("d=" + d.ToString());
                Log.Debug("y=" + y.ToString());
                Log.Debug("h=" + h.ToString());
                Log.Debug("m=" + m.ToString());
                Log.Debug("s=" + s.ToString());
                Log.Debug("str_s=" + str_s);
                Log.Debug("");*/

                GUIPropertyManager.SetProperty("#stardate.label", str_stardate);
            }
        }
    }
}
